==> azure_core-0.2.0.crate: azure_core-0.2.0/src/request_options/mod.rs <==
mod activity_id;
mod ba512_range;
mod client_request_id;
mod content_disposition;
mod content_encoding;
mod content_language;
mod content_type;
mod continuation;
mod delimiter;
mod if_match_condition;
mod if_modified_since;
mod if_modified_since_condition;
mod if_source_match_condition;
mod if_source_modified_since_condition;
mod lease;
mod lease_break_period;
mod lease_duration;
mod max_results;
mod metadata;
mod next_marker;
mod prefix;
mod proposed_lease_id;
mod range;
mod sequence_number;
mod sequence_number_condition;
mod source_content_md5;
mod source_lease_id;
mod timeout;
mod user_agent;

pub use activity_id::ActivityId;
pub use ba512_range::BA512Range;
pub use client_request_id::ClientRequestId;
pub use content_disposition::ContentDisposition;
pub use content_encoding::ContentEncoding;
pub use content_language::ContentLanguage;
pub use content_type::ContentType;
pub use continuation::Continuation;
pub use delimiter::Delimiter;
pub use if_match_condition::IfMatchCondition;
pub use if_modified_since::IfModifiedSince;
pub use if_modified_since_condition::IfModifiedSinceCondition;
pub use if_source_match_condition::IfSourceMatchCondition;
pub use if_source_modified_since_condition::IfSourceModifiedSinceCondition;
pub use lease::LeaseId;
pub use lease_break_period::LeaseBreakPeriod;
pub use lease_duration::LeaseDuration;
pub use max_results::MaxResults;
pub use metadata::Metadata;
pub use next_marker::NextMarker;
pub use prefix::Prefix;
pub use proposed_lease_id::ProposedLeaseId;
pub use range::Range;
pub use sequence_number::SequenceNumber;
pub use sequence_number_condition::SequenceNumberCondition;
pub use source_content_md5::SourceContentMD5;
pub use source_lease_id::SourceLeaseId;
pub use timeout::Timeout;
pub use user_agent::UserAgent;

==> azure_core-0.2.1.crate: azure_core-0.2.1/src/request_options/mod.rs <==
mod activity_id;
mod client_request_id;
mod content_disposition;
mod content_encoding;
mod content_language;
mod content_length;
mod content_range;
mod content_type;
mod continuation;
mod delimiter;
mod if_match_condition;
mod if_modified_since;
mod if_modified_since_condition;
mod if_source_match_condition;
mod if_source_modified_since_condition;
mod lease;
mod lease_break_period;
mod lease_duration;
mod max_item_count;
mod max_results;
mod metadata;
mod next_marker;
mod prefix;
mod proposed_lease_id;
mod range;
mod sequence_number;
mod sequence_number_condition;
mod source_lease_id;
mod timeout;
mod user_agent;

pub use activity_id::ActivityId;
pub use client_request_id::ClientRequestId;
pub use content_disposition::ContentDisposition;
pub use content_encoding::ContentEncoding;
pub use content_language::ContentLanguage;
pub use content_length::ContentLength;
pub use content_range::ContentRange;
pub use content_type::ContentType;
pub use continuation::Continuation;
pub use delimiter::Delimiter;
pub use if_match_condition::IfMatchCondition;
pub use if_modified_since::IfModifiedSince;
pub use if_modified_since_condition::IfModifiedSinceCondition;
pub use if_source_match_condition::IfSourceMatchCondition;
pub use if_source_modified_since_condition::IfSourceModifiedSinceCondition;
pub use lease::LeaseId;
pub use lease_break_period::LeaseBreakPeriod;
pub use lease_duration::LeaseDuration;
pub use max_item_count::MaxItemCount;
pub use max_results::MaxResults;
pub use metadata::Metadata;
pub use next_marker::NextMarker;
pub use prefix::Prefix;
pub use proposed_lease_id::ProposedLeaseId;
pub use range::Range;
pub use sequence_number::SequenceNumber;
pub use sequence_number_condition::SequenceNumberCondition;
pub use source_lease_id::SourceLeaseId;
pub use timeout::Timeout;
pub use user_agent::UserAgent;
